@@ -8,7 +8,7 @@ from . import parse_xml
 from .ns import nsdecls
 from .simpletypes import (
     ST_Coordinate, ST_DrawingElementId, ST_PositiveCoordinate,
-    ST_RelationshipId, XsdString, XsdToken
+    ST_RelationshipId, XsdString, XsdToken, XsdBoolean
 )
 from .xmlchemy import (
     BaseOxmlElement, OneAndOnlyOne, OptionalAttribute, RequiredAttribute,
@@ -57,6 +57,20 @@ class CT_Inline(BaseOxmlElement):
     extent = OneAndOnlyOne('wp:extent')
     docPr = OneAndOnlyOne('wp:docPr')
     graphic = OneAndOnlyOne('a:graphic')
+    wrapNone = ZeroOrOne('wp:wrapNone')
+    wrapSquare = ZeroOrOne('wp:wrapSquare')
+    wrapThrough = ZeroOrOne('wp:wrapThrough')
+    wrapTight = ZeroOrOne('wp:wrapTight')
+    wrapTopAndBottom = ZeroOrOne('wp:wrapTopAndBottom')
+
+    @property
+    def has_wrap(self):
+        if self.wrapNone:
+            return False
+        if self.wrapSquare or self.wrapThrough or self.wrapTight or self.wrapTopAndBottom:
+            return True
+        return False
+
 
     @classmethod
     def new(cls, cx, cy, shape_id, pic):
@@ -90,19 +104,107 @@ class CT_Inline(BaseOxmlElement):
     @classmethod
     def _inline_xml(cls):
         return (
-            '<wp:inline %s>\n'
-            '  <wp:extent cx="914400" cy="914400"/>\n'
-            '  <wp:docPr id="666" name="unnamed"/>\n'
-            '  <wp:cNvGraphicFramePr>\n'
-            '    <a:graphicFrameLocks noChangeAspect="1"/>\n'
-            '  </wp:cNvGraphicFramePr>\n'
-            '  <a:graphic>\n'
-            '    <a:graphicData uri="URI not set"/>\n'
-            '  </a:graphic>\n'
-            '</wp:inline>' % nsdecls('wp', 'a', 'pic', 'r')
+                '<wp:inline %s>\n'
+                '  <wp:extent cx="914400" cy="914400"/>\n'
+                '  <wp:docPr id="666" name="unnamed"/>\n'
+                '  <wp:cNvGraphicFramePr>\n'
+                '    <a:graphicFrameLocks noChangeAspect="1"/>\n'
+                '  </wp:cNvGraphicFramePr>\n'
+                '  <a:graphic>\n'
+                '    <a:graphicData uri="URI not set"/>\n'
+                '  </a:graphic>\n'
+                '</wp:inline>' % nsdecls('wp', 'a', 'pic', 'r')
         )
 
 
+class CT_Drawing(BaseOxmlElement):
+    """
+    Used for ``w:drawing``
+    """
+    anchor = OneAndOnlyOne('wp:anchor')
+
+
+class CT_Anchor(BaseOxmlElement):
+    """
+    Used for ``wp:anchor``
+    """
+    is_simplePos = RequiredAttribute('simplePos', XsdBoolean)
+    positionH = ZeroOrOne('wp:positionH')
+    positionV = ZeroOrOne('wp:positionV')
+    simplePos = ZeroOrOne('wp:simplePos')
+    graphic = OneAndOnlyOne('a:graphic')
+    wrapNone = ZeroOrOne('wp:wrapNone')
+    wrapSquare = ZeroOrOne('wp:wrapSquare')
+    wrapThrough = ZeroOrOne('wp:wrapThrough')
+    wrapTight = ZeroOrOne('wp:wrapTight')
+    wrapTopAndBottom = ZeroOrOne('wp:wrapTopAndBottom')
+
+    @property
+    def has_wrap(self):
+        if self.wrapNone is not None:
+            return False
+        if self.wrapSquare is not None or self.wrapThrough is not None or \
+                self.wrapTight is not None or self.wrapTopAndBottom is not None:
+            return True
+        return False
+
+
+class CT_WrapNone(BaseOxmlElement):
+    """
+    Used for ``wp:wrapNone``
+    """
+
+
+class CT_WrapSquare(BaseOxmlElement):
+    """
+    Used for ``wp:wrapSquare``
+    """
+
+
+class CT_WrapThrough(BaseOxmlElement):
+    """
+    Used for ``wp:wrapThrough``
+    """
+
+
+class CT_WrapTight(BaseOxmlElement):
+    """
+    Used for ``wp:wrapTight``
+    """
+
+
+class CT_WrapTopAndBottom(BaseOxmlElement):
+    """
+    Used for ``wp:wrapTopAndBottom``
+    """
+
+
+class CT_PositionH(BaseOxmlElement):
+    """
+    Used for ``wp:positionH``
+    """
+    relativeFrom = RequiredAttribute('relativeFrom', XsdString)
+    posOffset = ZeroOrOne('wp:posOffset')
+    align = ZeroOrOne('wp:align')
+
+    @property
+    def value(self):
+        return Emu(self.posOffset.text if self.posOffset is not None else 0)
+
+
+class CT_PositionV(BaseOxmlElement):
+    """
+    Used for ``wp:positionV``
+    """
+    relativeFrom = RequiredAttribute('relativeFrom', XsdString)
+    posOffset = ZeroOrOne('wp:posOffset')
+    align = ZeroOrOne('wp:align')
+
+    @property
+    def value(self):
+        return Emu(self.posOffset.text if self.posOffset is not None else 0)
+
+
 class CT_NonVisualDrawingProps(BaseOxmlElement):
     """
     Used for ``<wp:docPr>`` element, and perhaps others. Specifies the id and
@@ -161,25 +263,25 @@ class CT_Picture(BaseOxmlElement):
     @classmethod
     def _pic_xml(cls):
         return (
-            '<pic:pic %s>\n'
-            '  <pic:nvPicPr>\n'
-            '    <pic:cNvPr id="666" name="unnamed"/>\n'
-            '    <pic:cNvPicPr/>\n'
-            '  </pic:nvPicPr>\n'
-            '  <pic:blipFill>\n'
-            '    <a:blip/>\n'
-            '    <a:stretch>\n'
-            '      <a:fillRect/>\n'
-            '    </a:stretch>\n'
-            '  </pic:blipFill>\n'
-            '  <pic:spPr>\n'
-            '    <a:xfrm>\n'
-            '      <a:off x="0" y="0"/>\n'
-            '      <a:ext cx="914400" cy="914400"/>\n'
-            '    </a:xfrm>\n'
-            '    <a:prstGeom prst="rect"/>\n'
-            '  </pic:spPr>\n'
-            '</pic:pic>' % nsdecls('pic', 'a', 'r')
+                '<pic:pic %s>\n'
+                '  <pic:nvPicPr>\n'
+                '    <pic:cNvPr id="666" name="unnamed"/>\n'
+                '    <pic:cNvPicPr/>\n'
+                '  </pic:nvPicPr>\n'
+                '  <pic:blipFill>\n'
+                '    <a:blip/>\n'
+                '    <a:stretch>\n'
+                '      <a:fillRect/>\n'
+                '    </a:stretch>\n'
+                '  </pic:blipFill>\n'
+                '  <pic:spPr>\n'
+                '    <a:xfrm>\n'
+                '      <a:off x="0" y="0"/>\n'
+                '      <a:ext cx="914400" cy="914400"/>\n'
+                '    </a:xfrm>\n'
+                '    <a:prstGeom prst="rect"/>\n'
+                '  </pic:spPr>\n'
+                '</pic:pic>' % nsdecls('pic', 'a', 'r')
         )
 
 
